==> haskell-aws-0.24.1-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aws
version:              0.24.1
visibility:           public
id:                   aws-0.24.1-1NQRZiU4WKX9SwWd3YeoUR
key:                  aws-0.24.1-1NQRZiU4WKX9SwWd3YeoUR
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  f3f4b42bbf14b7eed3120ad8e2b38fd2
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aws-0.24.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24.1-1NQRZiU4WKX9SwWd3YeoUR
depends:
    aeson-2.1.2.1-KHwyqlRT8uq4KliO3neHti
    attoparsec-0.14.4-1LkqTl6pHdPB5xyeiPPJjY base-4.17.2.1
    base16-bytestring-1.0.2.0-KKJHyXdd0JLBsnAOn3nNgN
    base64-bytestring-1.2.1.0-F6smDE5HGDf8fxaFSXDtqF
    blaze-builder-0.4.4.1-8Il4GtRfluw9v81oKWussj
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    case-insensitive-1.2.1.0-H8Fvgv7YDBkYcnBQIbjuM
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    conduit-1.3.6.1-AhGLvUg5hIU6LsM4QL1rg6
    conduit-extra-1.3.8-JYWbaceofIoEWZCrj7lr7T containers-0.6.7
    cryptonite-0.30-3or9GN8ZZBQ2PL99Bs0SvH
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-tls-0.3.6.4-8td26AWajcgBrlQRooycma
    http-conduit-2.3.9.1-9oPlHGYlrOYaw1Zlna69I
    http-types-0.12.4-FtU8gz6pIQD8uIXzLWqrj
    lifted-base-0.2.3.12-KJvM774tIJVFiPFul3K1Yv
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-control-1.0.3.1-BOt9UiTcmLyI9gMDVX2E5U mtl-2.2.2
    network-3.1.4.0-Fdysxcu9OH32QGRZPBFSYA
    network-bsd-2.8.1.0-C8vJ62aadtcBQ7RU2ArwHo
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    resourcet-1.2.6-FfOnpJHT35xCMtTjhtEACj
    safe-0.3.21-F7VtiJ5GidLJaCroTndPfj
    scientific-0.3.8.0-FzkpGwEDtoiC1o6P6Xyy7X
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20.1-L9h8TvnOBH1Ihya3LZF9bU
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-EKABDCAVgb42yYEtp4rYAX
    xml-conduit-1.9.1.4-ATlJNrQIee7JTs8PjzVQNY

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.24.1-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aws
version:              0.24.1
visibility:           public
id:                   aws-0.24.1-FIPVa15afxY2UQB7Np75xu
key:                  aws-0.24.1-FIPVa15afxY2UQB7Np75xu
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  370c014f3cd135ea3dcddff7d0c6d9df
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.6.6/site-local/aws-0.24.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aws-0.24.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aws-0.24.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24.1-FIPVa15afxY2UQB7Np75xu
depends:
    aeson-2.1.2.1-2mQErQ8BnomI9IyqbCda9E
    attoparsec-0.14.4-75nKbPMSPaLAG220BErtuR base-4.18.2.1
    base16-bytestring-1.0.2.0-45sM9srzZ4HDD4PFMPeRP
    base64-bytestring-1.2.1.0-yECTd8pImc5tCLSmRqH7t
    blaze-builder-0.4.4.1-3wnAa360A0589gqzb0DfpQ
    byteable-0.1.1-3f80cduirhUG2oEjYYiPCW bytestring-0.11.5.3
    case-insensitive-1.2.1.0-5HTh5m1rt1RHDEKgWxawKc
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    conduit-1.3.6.1-CdT4yEwurtEjnovKY3L8i
    conduit-extra-1.3.8-4TbGFCZoahxAJpG0SOledp containers-0.6.7
    cryptonite-0.30-GDXPd4Usip610py58lI1cm
    data-default-0.7.1.3-DC0AJbPUVLOH54ZbhVmf2Q directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-tls-0.3.6.4-C9vh29ljq9FHtoEMbpBYyb
    http-conduit-2.3.9.1-5y2Zd6e4KUv3WKM5rmfeZ8
    http-types-0.12.4-47H2c8g9PRZ51oXX8MMJrI
    lifted-base-0.2.3.12-1PcQjgCoEV75P3xJCPGh1S
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-control-1.0.3.1-6BZrEcXVVy1ERiltg4JMsJ mtl-2.3.1
    network-3.1.4.0-IebBekr390i8Nw6inuvzzb
    network-bsd-2.8.1.0-5qoYeQ44n4L2jQi4qLTUb2
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    resourcet-1.2.6-EtMPDqHsQrqoGIXSo7kAd
    safe-0.3.21-J8yTbFjKPpT3oBMPyWIsQW
    scientific-0.3.8.0-DJ6xks3YjY5SsKPtBx4Fi
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-LJBbYvuM7Af6ez80tefkUA
    utf8-string-1.0.2-4PcjKdTUnsVIUZCxTUoFbK
    vector-0.13.2.0-6vtrErFI1tV1Z02auPMCSS
    xml-conduit-1.9.1.4-4egSc1tgxR2DRGp0ys5MCH

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
